@@ -1,8 +1,10 @@
-from typing import get_type_hints, TypeVar
+from typing import TypeVar
 
 # https://docs.soliditylang.org/en/v0.8.13/abi-spec.html#types
 int24 = TypeVar("int24")
 ...
+int128 = TypeVar("int128")
+...
 int256 = TypeVar("int256")
 
 uint8 = TypeVar("uint8")
