@@ -23,4 +23,4 @@ class Factory(Abi):
 # print(Factory.to_abi())
 
 
-print(ERC20.Approval.to_abi_item()["inputs"])
+print(ERC20().transferFrom.selector)
